@@ -38,7 +38,7 @@ public:
     explicit FullBackgroundWidget(QWidget *parent = nullptr);
     void paintEvent(QPaintEvent *event);
     void closeEvent(QCloseEvent *event);
-
+    void showEvent(QShowEvent *event);
 public Q_SLOTS:
     void onCursorMoved(const QPoint &pos);
     void lock();
@@ -57,7 +57,7 @@ private Q_SLOTS:
     void onGlobalKeyRelease(const QString &key);
     void onGlobalButtonDrag(int xPos, int yPos);
     void onPrepareForSleep(bool sleep);
-
+    void switchToLinux();
 private:
     QDBusInterface      *smInterface;
     LockWidget          *lockWidget;
