@@ -62,6 +62,8 @@ bool ScreenSaver::exists()
         return QFile(path).exists();
     case SAVER_IMAGE:
         return QDir(path).exists();
+    case SAVER_DEFAULT:
+	return true;
     }
 }
 
@@ -111,7 +113,7 @@ bool ScreenSaver::timerStatus()
 
 QDebug &operator<<(QDebug debug, const ScreenSaver &screensaver)
 {
-    QString modes[] = {"blank-only", "random", "single", "image"};
+    QString modes[] = {"blank-only", "random", "single", "image","default"};
     QString effects[] = {"none", "fade-in-out"};
     debug.nospace()<< "screensaver: "<< modes[screensaver.mode];
     switch(screensaver.mode) {
@@ -123,6 +125,8 @@ QDebug &operator<<(QDebug debug, const ScreenSaver &screensaver)
         break;
     case SAVER_IMAGE:
         debug.nospace() << screensaver.path << effects[screensaver.effect] << screensaver.interval;
+    case SAVER_DEFAULT:
+	break;
     }
 
     return debug.maybeSpace();
