@@ -27,7 +27,8 @@ enum SaverMode
     SAVER_BLANK_ONLY = 0,
     SAVER_RANDOM,
     SAVER_SINGLE,
-    SAVER_IMAGE
+    SAVER_IMAGE,
+    SAVER_DEFAULT
 };
 
 enum TransitionEffect
